@@ -25,11 +25,11 @@ GeomInteractiveBar <- ggproto(
   "GeomInteractiveBar",
   GeomBar,
   default_aes = add_default_interactive_aes(GeomBar),
-  draw_key = function(data, params, size) {
-    gr <- GeomBar$draw_key(data, params, size)
-    add_interactive_attrs(gr, data, data_attr = "key-id")
-  },
-  draw_panel = function(self, data, panel_params, coord, width = NULL, flipped_aes = FALSE) {
-    GeomInteractiveRect$draw_panel(data, panel_params, coord)
+  parameters = interactive_geom_parameters,
+  draw_key = interactive_geom_draw_key,
+  draw_panel = function(self, data, panel_params, coord, 
+                        width = NULL, flipped_aes = FALSE, 
+                        .ipar = IPAR_NAMES) {
+    GeomInteractiveRect$draw_panel(data, panel_params, coord, .ipar = .ipar)
   }
 )
