@@ -11,11 +11,9 @@ GeomInteractiveLinerange <- ggproto(
   "GeomInteractiveLinerange",
   GeomLinerange,
   default_aes = add_default_interactive_aes(GeomLinerange),
-  draw_key = function(data, params, size) {
-    gr <- GeomLinerange$draw_key(data, params, size)
-    add_interactive_attrs(gr, data, data_attr = "key-id")
-  },
-  draw_panel = function(data, panel_params, coord, flipped_aes = FALSE) {
+  parameters = interactive_geom_parameters,
+  draw_key = interactive_geom_draw_key,
+  draw_panel = function(data, panel_params, coord, flipped_aes = FALSE, .ipar = IPAR_NAMES) {
     data <- flip_data(data, flipped_aes)
     data <- transform(data,
                       xend = x,
@@ -24,7 +22,7 @@ GeomInteractiveLinerange <- ggproto(
     data <- flip_data(data, flipped_aes)
     ggname(
       "geom_linerange_interactive",
-      GeomInteractiveSegment$draw_panel(data, panel_params, coord)
+      GeomInteractiveSegment$draw_panel(data, panel_params, coord, .ipar = .ipar)
     )
   }
 )
