@@ -24,24 +24,12 @@ GeomInteractiveRaster <- ggproto(
   "GeomInteractiveRaster",
   GeomRaster,
   default_aes = add_default_interactive_aes(GeomRaster),
-  draw_key = function(data, params, size) {
-    gr <- GeomRaster$draw_key(data, params, size)
-    add_interactive_attrs(gr, data, data_attr = "key-id")
-  },
-  draw_panel = function(data, panel_params, coord, interpolate = FALSE,
-                        hjust = 0.5, vjust = 0.5) {
-    zz <- GeomRaster$draw_panel(
-      data,
-      panel_params,
-      coord,
-      interpolate = interpolate,
-      hjust = hjust,
-      vjust = vjust
-    )
+  parameters = interactive_geom_parameters,
+  draw_key = interactive_geom_draw_key,
+  draw_panel = function(data, panel_params, coord, ..., .ipar = IPAR_NAMES) {
+    zz <- GeomRaster$draw_panel(data, panel_params, coord, ...)
     coords <- coord$transform(data, panel_params)
-
     coords <- coords[1,, drop = FALSE]
-    coords <- force_interactive_aes_to_char(coords)
-    add_interactive_attrs(zz, coords)
+    add_interactive_attrs(zz, coords, ipar = .ipar)
   }
 )
