@@ -11,12 +11,14 @@ shinyServer(function(input, output, session) {
 
   output$plot <- renderGirafe({
     p <- ggplot(aes(x=wt,y=mpg, data_id = row.names(mtcars) ),data=mtcars) +
-      geom_point_interactive(size = 3) + theme_minimal()
+      geom_point_interactive(size = 4) + theme_minimal()
     girafe(
       ggobj = p,
+      width_svg = 7, height_svg = 2/3 * 7,
       options = list(
         opts_hover(css = "fill:red;cursor:pointer;"),
-        opts_selection(type = "single", css = "fill:red;")
+        opts_selection(type = "single", css = "fill:red;"),
+        opts_toolbar(saveaspng = FALSE)
       )
     )
   })
@@ -25,9 +27,9 @@ shinyServer(function(input, output, session) {
     value <- selected_car()
     if( !isTruthy(value) )
       value <- "<none>"
-    tags$div(
-      tags$caption("Selected point is:"),
-      tags$strong(value)
+    tags$button(type="button", class="btn btn-danger",
+      "Selected point is:",
+      tags$span(class="badge", tags$strong(value) )
     )
 
   })
